@@ -88,7 +88,7 @@ if __name__ == "__main__":
         'optimizeit_details': 3,
 
         'predicts': 12,
-        'compareit': 20,
+        'print_number_of_models': 20,
         'repeatit': 50,
         'return_type': 'best',
 
@@ -442,7 +442,7 @@ if __name__ == "__main__":
     sorted_results = np.argsort(model_results)
 
     if config['compareit']:
-        sorted_results = sorted_results[:config['compareit']]
+        sorted_results = sorted_results[:config['print_number_of_models']]
     else:
         sorted_results = sorted_results[0]
 
